@@ -111,8 +111,8 @@ OC.L10N.register(
     "Message deleted by you" : "Ați șters mesajul",
     "Deleted user" : "Utilizator șters",
     "Unknown number" : "Număr necunoscut",
-    "You missed a call from {user}" : "Ați pierdut un apel de la {user}",
-    "You tried to call {user}" : "Ați încercat să apelați pe {user}",
+    "Administration" : "Administrare",
+    "System" : "Sistem",
     "{actor} ended the call with {user1} (Duration {duration})" : "{actor} a închis apelul cu {user1} (Durată {duration})",
     "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} a închis apelul cu {user1} și {user2} (Durată {duration})",
     "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} a încheiat apelul cu {user1}, {user2} și {user3} (Durată {duration})",
@@ -136,11 +136,8 @@ OC.L10N.register(
     "Call in progress" : "Videoconferință în curs",
     "You were mentioned" : "Ați fost menționat",
     "Write to conversation" : "Postați în conversație",
-    "%s invited you to a conversation." : "%s v-a invitat într-o conversație.",
-    "You were invited to a conversation." : "Ați fost invitat într-o conversație.",
     "Conversation invitation" : "Invitație în conversație",
-    "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
-    "Join »%s«" : "Alăturați-vă »%s«",
+    "Description" : "Descriere",
     "Meeting ID" : "ID întâlnire",
     "Password request: %s" : "Solicitare parolă: %s",
     "Private conversation" : "Conversație privată",
@@ -151,6 +148,9 @@ OC.L10N.register(
     "Transcript now available" : "Transcrierea este acum disponibilă",
     "Accept" : "Accept",
     "Decline" : "Refuză",
+    "New message" : "Mesaj nou",
+    "Reminder" : "Memento",
+    "Notification" : "Notificări",
     "{user} reacted with {reaction}" : "{user} a reacționat cu {reaction}",
     "{user} reacted with {reaction} in {call}" : "{user} a reacționat cu {reaction} în {call}",
     "{user} in {call}" : "{user} în {call}",
@@ -170,12 +170,12 @@ OC.L10N.register(
     "{user} mentioned you in conversation {call}" : "{user} v-a menționat în conversația {call}",
     "View message" : "Vedeți mesajul",
     "View chat" : "Vedeți chat",
-    "{user} invited you to a private conversation" : "{user} v-a invitat într-o conversație privată",
-    "Join call" : "Participați la videoconferință",
     "{user} invited you to a group conversation: {call}" : "{user} v-a invitat la o conversație de grup: {call}",
+    "Join call" : "Participați la videoconferință",
     "Answer call" : "Răspundeți apelului",
     "{user} would like to talk with you" : "{user} ar dori să vorbiți",
     "Call back" : "Apelează înapoi",
+    "You missed a call from {user}" : "Ați pierdut un apel de la {user}",
     "A group call has started in {call}" : "A început un apel de grup în {call}",
     "You missed a group call in {call}" : "Ați pierdut un apel de grup în {call}",
     "{email} is requesting the password to access {file}" : "{email} solicită parola pentru a accesa {file}",
@@ -433,8 +433,8 @@ OC.L10N.register(
     "Federation" : "Federare",
     "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
     "Conversation not found" : "Conversație negăsită",
-    "Navigating away from the page will leave the call in {conversation}" : "Părăsind pagina se va părăsi conversația {conversation}",
     "Leave call" : "Părăsește videoconferința",
+    "Navigating away from the page will leave the call in {conversation}" : "Părăsind pagina se va părăsi conversația {conversation}",
     "Stay in call" : "Rămâneți în videoconferință",
     "Discuss this file" : "Discutați acest fișier",
     "Share this file with others to discuss it" : "Partajați acest fișier cu ceilalți pentru a-l discuta",
@@ -446,8 +446,6 @@ OC.L10N.register(
     "Error occurred when joining the conversation" : "Eroare la încercarea de participare la conversație",
     "Close Talk sidebar" : "Închide bara laterală Talk",
     "Open Talk sidebar" : "Deschide bara laterală Talk",
-    "Limit to groups" : "Limitează pentru grupuri",
-    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Când este selectat cel puțin un grup, doar persoanele din grupurile listate pot lua parte la conversație.",
     "Everyone" : "Toți",
     "Users and moderators" : "Utilizatori și moderatori",
     "Moderators only" : "Doar moderatori",
@@ -455,27 +453,29 @@ OC.L10N.register(
     "Save changes" : "Salvează modificările",
     "Saving …" : "Se salvează",
     "Saved!" : "Salvat!",
-    "State" : "Stadiu",
-    "Name" : "Nume",
-    "Description" : "Descriere",
-    "Last error" : "Ultima eroare",
-    "Total errors count" : "Total erori",
+    "Limit to groups" : "Limitează pentru grupuri",
+    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Când este selectat cel puțin un grup, doar persoanele din grupurile listate pot lua parte la conversație.",
     "Description is not provided" : "Nu este furnizată o descriere",
     "Locked for moderators" : "Blocat pentru moderatori",
     "Enabled" : "Activat",
     "Disabled" : "Dezactivați",
+    "State" : "Stadiu",
+    "Name" : "Nume",
+    "Last error" : "Ultima eroare",
+    "Total errors count" : "Total erori",
     "Beta" : "Beta",
     "Permissions" : "Permisiuni",
     "All messages" : "Toate mesajele",
     "Off" : "Oprit",
-    "Language" : "Limba",
-    "Country" : "Țară",
-    "Status" : "Stare",
-    "Created at" : "Creat la",
+    "Enable encryption" : "Activează criptarea",
     "Pending" : "În așteptare",
     "Error" : "Eroare",
     "Blocked" : "Blocat",
     "Active" : "Activ",
+    "Language" : "Limba",
+    "Country" : "Țară",
+    "Status" : "Stare",
+    "Created at" : "Creat la",
     "Downloading …" : "Se descarcă ...",
     "Failed" : "Eșuat",
     "OK" : "OK",
@@ -483,17 +483,25 @@ OC.L10N.register(
     "Automatically assign participants" : "Atribuie automat participanții",
     "Manually assign participants" : "Atribuie participanții manual",
     "Allow participants to choose" : "Permite participanților să aleagă",
+    "Confirm" : "Confirmă",
+    "Reset" : "Resetare",
     "Unassigned participants" : "Participanți neasociați",
     "Back" : "Înapoi",
     "Assign" : "Atribuie",
     "Cancel" : "Anulare",
-    "Confirm" : "Confirmă",
-    "Reset" : "Resetare",
     "Add participant \"{user}\"" : "Adaugă participant \"{user}\"",
+    "Now" : "Acum",
+    "From" : "De la",
+    "To" : "Către",
+    "Calendar" : "Calendar",
+    "Attendees" : "Participanți",
+    "Save" : "Salvează",
+    "Search participants" : "Caută participanți",
+    "No results" : "Niciun rezultat",
+    "Done" : "Realizat",
     "This conversation is read-only" : "Această conversație este read-only",
     "{nickName} raised their hand." : "{nickName} a ridicat mâna.",
     "A participant raised their hand." : "Un participant a ridicat mâna.",
-    "Copy link" : "Copiză link",
     "Connecting …" : "Se conectează ...",
     "Calling …" : "Se apelează ...",
     "Waiting for {user} to join the call" : "Se așteaptă ca {user} să intre în videoconferință",
@@ -501,6 +509,7 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "Puteți invita pe alții din tabul Participanți, în bara laterală",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Puteți invita pe alții din tabul Participanți din bara laterală sau să partajați acest link pentru a invita pe altcineva!",
     "Share this link to invite others!" : "Partajați acest link pentru a invita pe altcineva!",
+    "Copy link" : "Copiză link",
     "You are not allowed to enable audio" : "Nu aveți permisiunea de a activa sunetul",
     "No audio. Click to select device" : "Lipsă sunet. Click pentru selectare dispozitiv",
     "Mute audio" : "Oprire sunet",
@@ -519,20 +528,20 @@ OC.L10N.register(
     "Enable video (V)" : "Activează video (V) ",
     "Show presenter" : "Arată prezentatorul",
     "You" : "Tu",
-    "Show screen" : "Prezintă ecranul",
-    "Stop following" : "Oprire urmărire",
     "Mute" : "Oprește sunetul",
     "Muted" : "Sunet oprit",
+    "Show screen" : "Prezintă ecranul",
+    "Stop following" : "Oprire urmărire",
     "Collapse" : "Restrânge",
     "Expand" : "Extinde",
-    "Conversation messages" : "Mesajele conversației",
-    "Scroll to bottom" : "Derulează la sfârșit",
     "You need to be logged in to upload files" : "Trebuie să fiți autentificat pentru a încărca fișiere",
     "Drop your files to upload" : "Trageți fișierele pentru încărcare",
+    "Conversation messages" : "Mesajele conversației",
+    "Scroll to bottom" : "Derulează la sfârșit",
     "Favorite" : "Favorite",
+    "Date:" : "Data:",
     "Hide details" : "Ascunde detaliile",
     "Show details" : "Arată detaliile",
-    "Date:" : "Data:",
     "Enter a name for this conversation" : "Introduceți un nume pentru conversație",
     "Edit conversation name" : "Editează numele conversației",
     "Edit conversation description" : "Editează descrierea conversației",
@@ -540,24 +549,28 @@ OC.L10N.register(
     "Picture" : "Imagine",
     "Disable" : "Dezactivează",
     "Enable" : "Activare",
+    "Choose" : "Alege",
     "Upload conversation picture" : "Încarcă imaginea pentru conversație",
     "Choose conversation picture from files" : "Selectează imaginea conversației din Fișiere",
     "Remove conversation picture" : "Înlătură imaginea conversației",
     "Set picture" : "Setează imaginea",
     "Choose your conversation picture" : "Alegeți imaginea conversației",
-    "Choose" : "Alege",
+    "Default permissions modified for {conversationName}" : "Permisiunile implicite modificate pentru  {conversationName}",
+    "Could not modify default permissions for {conversationName}" : "Nu au fost modificate permisiunile implicite pentru {conversationName}",
     "All permissions" : "Toate permisiunile",
     "Restricted" : "Restricționat",
     "Advanced permissions" : "Permisiuni avansate",
     "Edit permissions" : "Editare permisiuni",
-    "Default permissions modified for {conversationName}" : "Permisiunile implicite modificate pentru  {conversationName}",
-    "Could not modify default permissions for {conversationName}" : "Nu au fost modificate permisiunile implicite pentru {conversationName}",
+    "Meeting" : "Videoconferință",
     "Conversation settings" : "Configurația conversației",
     "Basic Info" : "Informații de bază",
     "Personal" : "Personal",
     "Always show the device preview screen before joining a call in this conversation." : "Arată întotdeauna o previzualizare a ecranului dispozitvului înainte de a participa la această conversație.",
     "Moderation" : "Moderare",
-    "Meeting" : "Videoconferință",
+    "Do you really want to delete \"{displayName}\"?" : "Sigur ștergeți \"{displayName}\"?",
+    "Do you really want to delete all messages in \"{displayName}\"?" : "Sigur ștergeți toate mesajele din \"{displayName}\"?",
+    "Error while deleting conversation" : "Eroare la ștergerea conversației",
+    "Error while clearing chat history" : "Eroare la ștergerea istoricului de chat",
     "Leave conversation" : "Părăsiți conversația",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Odată ce ați părăsit o conversație, pentru a vă realătura aveți nevoie de o invitație. Conversațiile deschise pot fi accesate oricând.",
     "No" : "Nu",
@@ -567,117 +580,104 @@ OC.L10N.register(
     "Delete chat messages" : "Șterge mesajele de chat",
     "Permanently delete all the messages in this conversation." : "Șterge permanent toate mesajele din conversație",
     "Delete all chat messages" : "Șterge toate mesajele de chat",
-    "Do you really want to delete \"{displayName}\"?" : "Sigur ștergeți \"{displayName}\"?",
-    "Do you really want to delete all messages in \"{displayName}\"?" : "Sigur ștergeți toate mesajele din \"{displayName}\"?",
-    "Error while deleting conversation" : "Eroare la ștergerea conversației",
-    "Error while clearing chat history" : "Eroare la ștergerea istoricului de chat",
+    "Message expiration disabled" : "Expirarea mesajului dezactivată",
+    "Message expiration set: {duration}" : "Expirarea mesajului la: {duration}",
     "Message expiration" : "Expirare mesaj",
     "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Mesajele de chat pot fi configurate să expire după un timp. Notă: Fișierele partajate în chat nu vor fi șterse pentru posesor, dar nu vor mai fi partajate în conversație.",
     "Set message expiration" : "Setează expirarea mesajului",
     "Current message expiration" : "Data expirării mesajului",
-    "Message expiration disabled" : "Expirarea mesajului dezactivată",
-    "Message expiration set: {duration}" : "Expirarea mesajului la: {duration}",
     "Password protection" : "Password protection",
     "Enter new password" : "Introduceți o nouă parolă",
     "Save password" : "Salvează parola",
-    "Copy conversation link" : "Copiază linkul conversației",
     "Resend invitations" : "Trimite din nou invitațiile",
-    "Open conversation" : "Deschide conversația",
     "Error occurred when opening or limiting the conversation" : "Eroare la deschiderea sau la limitarea conversației ",
+    "Open conversation" : "Deschide conversația",
+    "Start time has been updated" : "Ora de început a fost actualizată",
     "Meeting start time" : "Ora de început a videoconferinței",
     "Start time (optional)" : "Ora de început (opțional)",
-    "Start time has been updated" : "Ora de început a fost actualizată",
     "Lock conversation" : "Blochează conversația",
     "This will also terminate the ongoing call." : "Aceasta va termina, de asemenea, videoconferința în curs.",
     "Lock the conversation to prevent anyone to post messages or start calls" : "Blocați conversația pentru a împiedica postarea mesajelor sau apelurile",
-    "Save" : "Salvează",
     "Edit" : "Editează",
     "More information" : "Mai multe informații",
     "Delete" : "Șterge",
     "Notifications" : "Notificări",
+    "Create a new conversation" : "Creează o nouă conversație",
+    "Unread mentions" : "Menționări necitite",
+    "Create conversation" : "Creați o conversație",
     "Enter your name" : "Introduceți numele",
     "Submit name and join" : "Transmite numele și participați",
-    "Login" : "Autentificare",
+    "Log in" : "Autentificare",
     "Search participants or phone numbers" : "Căutare participanți sau numere de telefon",
     "Creating the conversation …" : "Se creează conversația ...",
-    "Conversation actions" : "Acțiuni conversație",
     "Mark as read" : "Marchează ca citit",
     "Mark as unread" : "Marchează ca necitit",
     "Remove from favorites" : "Șterge din favorite",
     "Add to favorites" : "Adăugați la favorite",
-    "Conversation list" : "Lista de conversații",
-    "Filter unread mentions" : "Filtrează mențiunile necitite",
-    "Filter unread messages" : "Filtrează mesajele necitite",
-    "Clear filters" : "Șterge filtrele",
-    "Create a new conversation" : "Creează o nouă conversație",
-    "New personal note" : "Notă personală nouă",
-    "Clear filter" : "Șterge filtrul",
-    "Unread mentions" : "Menționări necitite",
+    "Conversation actions" : "Acțiuni conversație",
+    "Unread" : "Necitit",
     "No matches found" : "Nicio potrivire",
-    "Open conversations" : "Conversații deschise",
-    "Users" : "Utilizatori",
-    "Groups" : "Grupuri",
-    "No search results" : "Căutarea nu are rezultate",
-    "Loading" : "Loading",
-    "Talk settings" : "Setări Talk",
     "No conversations found" : "Nu sunt conversații",
     "You have no unread mentions." : "Nu aveți menționări necitite.",
     "You have no unread messages." : "Nu aveți mesaje necitite.",
+    "Conversation list" : "Lista de conversații",
+    "Clear filters" : "Șterge filtrele",
+    "New personal note" : "Notă personală nouă",
+    "Clear filter" : "Șterge filtrul",
+    "Talk settings" : "Setări Talk",
+    "Users" : "Utilizatori",
+    "Groups" : "Grupuri",
+    "Open conversations" : "Conversații deschise",
+    "No search results" : "Căutarea nu are rezultate",
     "Users and groups" : "Utilizatori și grupuri",
     "Other sources" : "Alte surse",
     "The meeting will start soon" : "Întâlnirea va începe în curând",
     "None" : "Niciuna",
     "Devices" : "Dispozitive",
+    "Invalid path selected" : "Calea selectată este invalidă",
     "Blur" : "Blurează",
     "Upload" : "Încărcare",
     "Files" : "Fișiere",
-    "Invalid path selected" : "Calea selectată este invalidă",
     "Message sent" : "Mesajul a fost transmis",
+    "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
+    "Set reminder for later today" : "Setează memo pentru azi, mai târziu",
+    "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
+    "Set reminder for tomorrow" : "Setează memo pentru mâine",
+    "This weekend – {timeLocale}" : "În acest weekend – {timeLocale}",
+    "Set reminder for this weekend" : "Setează memo pentru acest weekend",
+    "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
+    "Set reminder for next week" : "Setează memo pentru săptămâna viitoare",
+    "Clear reminder – {timeLocale}" : "Șterge memento – {timeLocale}",
     "Reply" : "Răspunde",
     "Set reminder" : "Setează memo",
     "Edit message" : "Editare mesaj",
     "Translate" : "Tradu",
     "Set custom reminder" : "Setează memento particular",
-    "Set reminder for later today" : "Setează memo pentru azi, mai târziu",
-    "Set reminder for tomorrow" : "Setează memo pentru mâine",
-    "Set reminder for this weekend" : "Setează memo pentru acest weekend",
-    "Set reminder for next week" : "Setează memo pentru săptămâna viitoare",
     "Dismiss" : "Elimină",
     "Contact" : "Contact",
     "{stack} in {board}" : "{stack} în {board}",
-    "No messages" : "Niciun mesaj",
     "Today" : "Azi",
     "Yesterday" : "Ieri",
     "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
-    "Search participants" : "Caută participanți",
+    "No messages" : "Niciun mesaj",
     "Cancel search" : "Renunță la căutare",
-    "Create a new group conversation" : "Creați o nouă conversație de grup",
-    "Create conversation" : "Creați o conversație",
-    "Add participants" : "Adăugați participanți",
-    "Close" : "Închide",
     "All set, the conversation \"{conversationName}\" was created." : "Totul a fost configurat, conversația \"{conversationName}\" a fost creată.",
+    "Create a new group conversation" : "Creați o nouă conversație de grup",
+    "Add participants" : "Adăugați participanți",
     "Conversation visibility" : "Vizibilitatea conversației",
-    "Password protect" : "Protejare cu parolă",
     "Enter password" : "Introduceți parola",
+    "Joining conversation …" : "Alăturare la conversație ...",
     "Cancel editing" : "Anulează editarea",
     "File to share" : "Fișier de partajat",
-    "Joining conversation …" : "Alăturare la conversație ...",
-    "Upload from device" : "Încarcă din dispozitiv",
     "Share from Files" : "Partajează din Fișiere",
+    "Upload from device" : "Încarcă din dispozitiv",
     "New file" : "Fișier nou",
     "Blank" : "Gol",
+    "Send" : "Trimite",
     "Question" : "Întrebare",
     "Settings" : "Setări",
-    "Send" : "Trimite",
-    "guest" : "invitat",
-    "Demote from moderator" : "Depromovează de la moderator",
-    "Promote to moderator" : "Promovează la moderator",
-    "Resend invitation" : "Retransmite invitația",
-    "Send call notification" : "Trimite notificare de apel",
-    "Grant all permissions" : "Acordă toate permisiunile",
-    "Remove all permissions" : "Elimină toate permisiunile",
-    "Remove" : "Elimină",
     "Settings for participant \"{user}\"" : "Setări pentru  participant \"{user}\"",
+    "guest" : "invitat",
     "Ringing …" : "Apel …",
     "Raised their hand" : "Au ridicat mâna",
     "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Textul trebuie să fie mai scurt sau egal cu {maxLength} caractere. Textul curent are {charactersCount} caractere.",
@@ -689,46 +689,62 @@ OC.L10N.register(
     "Could not modify permissions for {displayName}" : "Nu au fost modificate permisiunile pentrur {displayName}",
     "Permissions removed for {displayName}" : "Au fost eliminate permisiunile pentru {displayName}",
     "Permissions set to default for {displayName}" : "Au fost aplicate permisiunile implicite pentru {displayName}",
+    "Demote from moderator" : "Depromovează de la moderator",
+    "Promote to moderator" : "Promovează la moderator",
+    "Resend invitation" : "Retransmite invitația",
+    "Send call notification" : "Trimite notificare de apel",
+    "Grant all permissions" : "Acordă toate permisiunile",
+    "Remove all permissions" : "Elimină toate permisiunile",
+    "Remove" : "Elimină",
     "Permissions modified for {displayName}" : "Au fost modificate permisiunile pentru {displayName}",
+    "Add users or groups" : "Add users or groups",
     "Add users" : "Adaugă utilizatori",
     "Add groups" : "Adaugă grupuri",
+    "Add other sources" : "Adaugă alte surse",
     "Add emails" : "Adaugă emailuri",
     "Integrations" : "Integrări",
     "Searching …" : "Căutare ...",
-    "No results" : "Niciun rezultat",
     "Search for more users" : "Căutare mai mulți utilizatori",
-    "Add users or groups" : "Add users or groups",
-    "Add other sources" : "Adaugă alte surse",
-    "Participants" : "Participanți",
     "Search or add participants" : "Căutare sau adăugare participanți",
     "Invitation was sent to {actorId}" : "Invitația a fost trimisă către {actorId}",
     "An error occurred while adding the participants" : "Eroare la adăugarea participanților",
-    "Details" : "Detalii",
-    "Shared items" : "Elemente partajate",
+    "Participants" : "Participanți",
     "Participants ({count})" : "Participanți ({count})",
     "Open chat" : "Dechide chat",
     "You have new unread messages in the chat." : "Aveți mesaje necitite în chat",
     "You have been mentioned in the chat." : "Ați fost menționat în chat",
+    "Details" : "Detalii",
+    "Shared items" : "Elemente partajate",
+    "No results found" : "Nu s-a găsit nimic",
+    "Load more results" : "Încarcă mai multe rezultate",
     "Projects" : "Proiecte",
     "No shared items" : "Nicio partajare",
-    "Search conversations or users" : "Căutare conversații sau utilizatori",
-    "Select conversation" : "Selectare conversație",
     "Link to a conversation" : "Link la conversație",
     "No open conversations found" : "Nu au fost găsite conversații deschise",
     "Either there are no open conversations or you joined all of them." : "Nu sunt conversații deschise sau participați la toate",
     "Check spelling or use complete words." : "Verificați ortografia sau folosiți cuvinte întregi",
-    "Phone numbers" : "Numere de telefon",
+    "Search conversations or users" : "Căutare conversații sau utilizatori",
+    "Select conversation" : "Selectare conversație",
     "Number length is not valid" : "Lungime număr incorectă",
+    "Phone numbers" : "Numere de telefon",
     "Save name" : "Salvează numele",
-    "Display name: {name}" : "Numele afișat: {name}",
     "Calls are not supported in your browser" : "Apelurile video nu sunt suportate de browser",
     "Access to microphone was denied" : "Accesul la microfon a fost respins",
     "Error while accessing microphone" : "Eroare la accesarea microfonului",
+    "Choose the folder in which attachments should be saved." : "Selectați folderul în care se vor salva atașamentele",
+    "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
+    "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
+    "Error while setting read status privacy" : "Eroare la setarea confidențialității statusului de citire",
+    "Error while setting typing status privacy" : "Eroare la setarea confidențialității tastării",
+    "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
+    "Sounds setting saved" : "Setările de sunet au fost salvate",
+    "Error while saving sounds setting" : "Eroare la salvarea setărilor de sunet",
     "Choose devices" : "Selectați dispozitivele",
     "Attachments folder" : "Dosarul pentru atașamente",
     "Browse …" : "Navigare ...",
     "Select location for attachments" : "Selectați locația atașamentelor",
-    "Privacy" : "Confindențialitate",
+    "Appearance" : "Aspect",
+    "Privacy" : "Confidențialitate",
     "Share my read-status and show the read-status of others" : "Arată statusul meu de citire și pe al celorlalți",
     "Share my typing-status and show the typing-status of others" : "Arată când tastez eu și ceilalți",
     "Sounds" : "Sunete",
@@ -748,24 +764,14 @@ OC.L10N.register(
     "Space bar" : "Bara de spațiu",
     "Push to talk or push to mute" : "Apăsați pentru a vorbi sau pentru a suprima microfonul",
     "Raise or lower hand" : "Ridicare sau coborâre mână",
-    "Choose the folder in which attachments should be saved." : "Selectați folderul în care se vor salva atașamentele",
-    "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
-    "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
-    "Error while setting read status privacy" : "Eroare la setarea confidențialității statusului de citire",
-    "Error while setting typing status privacy" : "Eroare la setarea confidențialității tastării",
-    "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
-    "Sounds setting saved" : "Setările de sunet au fost salvate",
-    "Error while saving sounds setting" : "Eroare la salvarea setărilor de sunet",
-    "End call for everyone" : "Închide videoconferința pentru toți",
     "Start call silently" : "Pornește videoconferința fără sunet",
     "Start call" : "Pornește videoconferința",
     "End call" : "Închidere videoconferință",
     "You will be able to join the call only after a moderator starts it." : "Veți putea să participați după ce videoconferința va fi pornită de un moderator",
+    "End call for everyone" : "Închide videoconferința pentru toți",
     "The call has been running for one hour." : "Videoconferința durează de o oră",
     "Send a reaction" : "Trimite o reacție",
     "React with {reaction}" : "Reacționează cu {reaction}",
-    "Show your screen" : "Prezentați ecranul",
-    "Stop screensharing" : "Oprește partajarea ecranului",
     "Disable background blur" : "Dezactivează blurarea fundalului",
     "Blur background" : "Blurează fundalul",
     "You are not allowed to enable screensharing" : "Nu aveți permisiunea de partajare a ecranului",
@@ -783,8 +789,8 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Partajarea ecranului nu e posibilă în acest browser.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Folosiți un alt browser precum Firefox și Chrome pentru partajarea ecranului.",
     "An error occurred while starting screensharing." : "Eroare la partajarea ecranului.",
-    "Mute others" : "Închide microfonul celorlalți",
-    "Toggle full screen" : "Comută în ecran complet",
+    "Show your screen" : "Prezentați ecranul",
+    "Stop screensharing" : "Oprește partajarea ecranului",
     "Exit full screen (F)" : "Ieșire din ecran complet (F)",
     "Full screen (F)" : "Ecran complet (F)",
     "Speaker view" : "Vizualizare vorbitor",
@@ -793,7 +799,10 @@ OC.L10N.register(
     "Raise hand (R)" : "Ridică mâna (R)",
     "Lower hand" : "Coboară mâna",
     "Lower hand (R)" : "Coboară mâna (R)",
+    "Mute others" : "Închide microfonul celorlalți",
+    "Toggle full screen" : "Comută în ecran complet",
     "Remove participant {name}" : "Elimină participantul {name}",
+    "Keep" : "Păstrare",
     "Select a region" : "Selectează o regiune",
     "Submit" : "Trimite",
     "Search …" : "Caută ...",
@@ -803,14 +812,11 @@ OC.L10N.register(
     "Join a conversation or start a new one!" : "Particiăați la o conversație sau creați una nouă!",
     "Duplicate session" : "Sesiune duplicat",
     "Join a conversation or start a new one" : "Participați la o conversație sau începeți una nouă",
-    "Clear reminder – {timeLocale}" : "Șterge memento – {timeLocale}",
-    "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
-    "This weekend – {timeLocale}" : "În acest weekend – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
-    "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
+    "Display name: {name}" : "Numele afișat: {name}",
     "Talk conversation" : "Conversație Talk",
     "User" : "Utilizator",
     "Password" : "Parolă",
+    "Login" : "Autentificare",
     "Nickname" : "Pseudonim",
     "Client ID" : "ID client",
     "Media" : "Media",
@@ -829,6 +835,7 @@ OC.L10N.register(
     "Show all audio" : "Arată audio",
     "Show all other" : "Arată celelalte",
     "Group" : "Grup",
+    "Team" : "Echipă",
     "You reconnected to the call" : "V-ați reconectat",
     "{actor} reconnected to the call" : "{actor} s-a reconectat",
     "You added {user0} and {user1}" : "Ați adăugat pe {user0} și {user1}",
@@ -837,8 +844,10 @@ OC.L10N.register(
     "An administrator added {user0} and {user1}" : "Un administrator a adăugat pe {user0} și pe {user1}",
     "{actor} added {user0} and {user1}" : "{actor} a adăugat pe {user0} și pe {user1}",
     "You: {lastMessage}" : "Tu: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Încercați să participați la o conversație având o sesiune activă în altă fereastră sau dispozitiv. Acest lucru nu este suportat în prezent în Nextcloud Talk. Ce doriți să faceți?",
+    "Leave this page" : "Părăsește pagina",
+    "Join here" : "Alăturare aici",
     "Deck card has been posted to {conversation}" : "Cardul Deck a fost postat la conversația {conversation}",
-    "Error while sharing file" : "Eroare la partajarea fișierului",
     "Error while clearing conversation history" : "Eroare la ștergerea istoricului conversației",
     "Conversation password has been saved" : "Parola conversației a fost salvată",
     "Conversation password has been removed" : "Parola conversație a fost ștearsă",
@@ -846,15 +855,11 @@ OC.L10N.register(
     "Conversation picture deleted" : "Imaginea conversației a fost ștearsă",
     "Error while uploading file \"{fileName}\"" : "Eroare la încărcarea fișierului \"{fileName}\"",
     "Not enough free space to upload file \"{fileName}\"" : "Spațiu insuficient pentru încărcarea fișierului \"{fileName}\"",
-    "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
+    "Error while sharing file" : "Eroare la partajarea fișierului",
     "Could not post message: {errorMessage}" : "Nu s-a putut posta mesajul: {errorMessage}",
     "An error occurred while fetching the participants" : "Eroare la preluarea listei de participanți",
     "Could not send invitation to {actorId}" : "Nu a fost trimisă invitația către {actorId}",
     "Invitations sent" : "Invitațiile au fost trimise",
-    "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. ",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Încercați să participați la o conversație având o sesiune activă în altă fereastră sau dispozitiv. Acest lucru nu este suportat în prezent în Nextcloud Talk. Ce doriți să faceți?",
-    "Join here" : "Alăturare aici",
-    "Leave this page" : "Părăsește pagina",
     "An error occurred while requesting assistance" : "Eroare la solicitarea de asistență",
     "An error occurred while resetting the request for assistance" : "Eroare la resetarea solicitării de asistență",
     "An error occurred while submitting your vote" : "Eroare la transmiterea votului",
@@ -864,6 +869,7 @@ OC.L10N.register(
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Browserul folosit nu este compatibil cu Nextcloud Talk. Folosiți ultima versiune a Mozilla Firefox, Microsoft Edge, Google Chrome sau Apple Safari.",
     "Conversation link copied to clipboard" : "Linkul conversației a fost copiat",
     "The link could not be copied" : "Linkul nu s-a putut copia",
+    "Please reload the page." : "Te rugăm să reîncarci pagina.",
     "Do not disturb" : "Nu deranja",
     "Away" : "Plecat",
     "Default" : "Implicit",
@@ -873,26 +879,20 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
     "Android app" : "Aplicație Android",
     "iOS app" : "Aplicație iOS",
-    "Call with {user1} and {user2} (Duration {duration})" : "Apel cu {user1} și {user2} (Durată {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Apelul cu {user1}, {user2} și {user3} (Durată {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Apel cu {user1}, {user2}, {user3} și {user4} (Durată {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Apel cu {user1}, {user2}, {user3}, {user4} și {user5} (Durată {duration})",
-    "More unread mentions" : "Mai multe menționări necitite",
-    "Response to" : "Răspuns la",
-    "Enabled for" : "Activat pentru",
-    "Moderators" : "Moderatori",
-    "The message could not be sent" : "Mesajul nu s-a putut transmite ",
-    "Delete Conversation" : "Șterge conversația",
-    "Circles" : "Cercuri",
-    "Users, groups and circles" : "Utilizatori, grupuri și cercuri",
-    "Users and circles" : "Utilizatori și cercuri",
-    "Groups and circles" : "Grupuri și cercuri",
-    "Add circles" : "Adaugă cercuri",
-    "Add users, groups or circles" : "Adaugă utilizatori, grupuri și cercuri",
-    "Add users or circles" : "Adaugă utilizatori și cercuri",
-    "Add groups or circles" : "Adaugă grupuri și cercuri",
-    "Start a conversation" : "Porniți o conversație",
-    "Post to conversation" : "Postare în conversație",
-    "Share to conversation" : "Partajare la conversație"
+    "__language_name__" : "Română",
+    "Tasks" : "Sarcini",
+    "Notes" : "Notițe",
+    "You tried to call {user}" : "Ați încercat să apelați pe {user}",
+    "%s invited you to a conversation." : "%s v-a invitat într-o conversație.",
+    "You were invited to a conversation." : "Ați fost invitat într-o conversație.",
+    "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
+    "Join »%s«" : "Alăturați-vă »%s«",
+    "{user} invited you to a private conversation" : "{user} v-a invitat într-o conversație privată",
+    "Copy conversation link" : "Copiază linkul conversației",
+    "Filter unread mentions" : "Filtrează mențiunile necitite",
+    "Filter unread messages" : "Filtrează mesajele necitite",
+    "Close" : "Închide",
+    "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
+    "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. "
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
