@@ -155,11 +155,8 @@ OC.L10N.register(
     "You were mentioned" : "Ses istadu mentovadu",
     "Write to conversation" : "Iscrie in sa resonada",
     "Writes event information into a conversation of your choice" : "Iscriet is informatziones de s'eventu in una resonada de sèberu tuo",
-    "%s invited you to a conversation." : "%s t'at invitadu in una resonada",
-    "You were invited to a conversation." : "T'ant invitadu in una resonada.",
     "Conversation invitation" : "Cumbidu a sa resonada",
-    "Click the button below to join." : "Incarca su butone a suta pro intrare.",
-    "Join »%s«" : "Intra in »%s«",
+    "Description" : "Descritzione",
     "You can also dial-in via phone with the following details" : "Ti podes connètere puru cun su telèfono cun is detàllios in fatu",
     "Dial-in information" : "Informatziones de connessione",
     "Meeting ID" : "ID de s'atòbiu",
@@ -170,6 +167,7 @@ OC.L10N.register(
     "Dismiss notification" : "Iscarta notìfica",
     "Accept" : "Atzeta",
     "Decline" : "Refuda",
+    "New message" : "Messàgiu nou",
     "{user} in {call}" : "{user} in {call}",
     "Deleted user in {call}" : "Utente cantzelladu in {call}",
     "{guest} (guest) in {call}" : "{guest} (utèntzia istràngia) in {call}",
@@ -381,7 +379,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "San Martin (parte Frantzesa)",
     "Madagascar" : "Madagascar",
     "Marshall Islands" : "Ìsulas Marshall",
-    "Macedonia, the former Yugoslav Republic of" : "Macedònia",
+    "North Macedonia" : "Macedònia de su Nord",
     "Mali" : "Mali",
     "Myanmar" : "Myanmar",
     "Mongolia" : "Mongòlia",
@@ -527,7 +525,6 @@ OC.L10N.register(
     "Disabled" : "Disabilitada",
     "State" : "Istadu",
     "Name" : "Nùmene",
-    "Description" : "Descritzione",
     "Beta" : "Beta",
     "Permissions" : "Permissos",
     "All messages" : "Totu is messàgios",
@@ -605,7 +602,6 @@ OC.L10N.register(
     "Cancel" : "Annulla",
     "Add participant \"{user}\"" : "Agiunghe partetzipante \"{user}\"",
     "Loading …" : "Carrigamentu …",
-    "No upcoming events" : "Perunu eventu abarradu",
     "From" : "Dae",
     "To" : "A",
     "Calendar" : "Calendàriu",
@@ -664,9 +660,9 @@ OC.L10N.register(
     "The file must be a PNG or JPG" : "S'archìviu depet èssere unu PNG o JPG",
     "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Ogni borta chi is permissos sunt modificados in custa setzione, is permissos personalizados assignados in pretzedèntzia a partetzipantes individuales ant a èssere pèrdidos.",
     "Restricted" : "Limitadu",
+    "Meeting" : "Atòbiu",
     "Conversation settings" : "Cunfiguratzione de sa resonada",
     "Personal" : "Personale",
-    "Meeting" : "Atòbiu",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zona de perìgulu",
     "Do you really want to delete \"{displayName}\"?" : "A beru boles cantzellare \"{displayName}\"?",
@@ -689,8 +685,6 @@ OC.L10N.register(
     "Save password" : "Sarva sa crae",
     "Resend invitations" : "Torra a imbiare is invitos",
     "Error occurred when opening or limiting the conversation" : "B'at àpidu un'errore aberrende o limitende sa resonada",
-    "Error occurred when restricting the conversation to moderator" : "B'at àpidu un'errore limitende sa resonada a chie moderat",
-    "Error occurred when opening the conversation to everyone" : "B'at àpidu un'errore aberrende sa resonada a totus",
     "Start time has been updated" : "S'ora de cumintzu est istada agiornada",
     "Error occurred while updating start time" : "B'at àpidu un'errore agiornende s'ora de cumintzu",
     "Meeting start time" : "Ora de cumintzu de sa riunione",
@@ -714,11 +708,14 @@ OC.L10N.register(
     "Show Matterbridge log" : "Mustra su registru de Matterbridge",
     "Log content" : "Cuntenutu de is registros",
     "Notifications" : "Notìficas",
+    "Important conversation" : "Tzarrada importante",
     "SIP dial-in is now enabled" : "S'atzessu SIP immoe est ativu",
     "SIP dial-in is now disabled" : "S'atzessu SIP immoe est disativu",
     "Error occurred when enabling SIP dial-in" : "B'at àpidu un'errore ativende s'atzessu SIP",
     "Error occurred when disabling SIP dial-in" : "B'at àpidu un'errore disativende s'atzessu SIP",
+    "Join" : "Intra",
     "Error while creating the conversation" : "Errore creende sa resonada ",
+    "Create a new conversation" : "Crea una resonada noa",
     "Create conversation" : "Crea resonada",
     "Enter your name" : "Inserta•nche su nùmene tuo",
     "Log in" : "Intra",
@@ -733,7 +730,7 @@ OC.L10N.register(
     "No conversations found" : "Peruna resonada agatada",
     "An error occurred while performing the search" : "B'at àpidu un'errore in sa chirca",
     "Conversation list" : "Lista de is resonadas",
-    "Create a new conversation" : "Crea una resonada noa",
+    "Unread messages" : "Messàgios non lèghidos",
     "New personal note" : "Nota personale noa",
     "Clear filter" : "Lìmpia filtru",
     "Talk settings" : "Cunfiguratzione de Talk",
@@ -765,7 +762,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Su messàgiu non si podet cantzellare ca est tropu betzu",
     "Only normal chat messages can be deleted" : "Si podent cantzellare isceti is messàgios de tzarrada normales",
     "An error occurred while deleting the message" : "B'at àpidu un'errore cantzellende su messàgiu",
-    "Unread messages" : "Messàgios non lèghidos",
     "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
     "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
     "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
@@ -830,7 +826,6 @@ OC.L10N.register(
     "Send" : "Imbia",
     "Settings" : "Cunfiguratzione",
     "Anonymous poll" : "Sondàgiu anònimu",
-    "Join" : "Intra",
     "Disable lobby" : "Disativa intrada",
     "Settings for participant \"{user}\"" : "Cunfiguratzione pro partetzipante \"{user}\"",
     "Participant \"{user}\"" : "Partetzipante \"{user}\"",
@@ -939,6 +934,7 @@ OC.L10N.register(
     "Lower hand" : "Bàscia sa manu ",
     "Lower hand (R)" : "Bàscia sa manu (R)",
     "Mute others" : "Tira s'àudio a àtere",
+    "Keep" : "Mantene",
     "Select a region" : "Seletziona una regione",
     "Submit" : "Imbia",
     "Message without mention" : "Messàgiu chena mentovu",
@@ -1000,9 +996,14 @@ OC.L10N.register(
     "Group" : "Grupu",
     "You: {lastMessage}" : "Tue: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ses proende a intrare in una resonada cun una sessione ativa in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk. Ite boles fàghere?",
+    "Leave this page" : "Lassa custa pàgina",
+    "Join here" : "Intra inoghe",
     "Error while clearing conversation history" : "Errore limpiende s'istòria de sa resonada",
     "Error occurred while allowing guests" : "B'at àpidu un'errore autorizende is persones invitadas",
     "Error occurred while disallowing guests" : "B'at àpidu un'errore refudende is persones invitadas",
+    "Error occurred when restricting the conversation to moderator" : "B'at àpidu un'errore limitende sa resonada a chie moderat",
+    "Error occurred when opening the conversation to everyone" : "B'at àpidu un'errore aberrende sa resonada a totus",
     "Conversation password has been saved" : "Sa crae de sa resonada est istada sarvada",
     "Conversation password has been removed" : "Sa crae de sa resonada nch'est istada bogada",
     "Error occurred while saving conversation password" : "B'at àpidu un'errore sarvende sa crae de sa resonada",
@@ -1014,9 +1015,6 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "No at fatu a imbiare s'invitu a {actorId}.",
     "Invitations sent" : "Invitos imbiados",
     "Error occurred when sending invitations" : "B'at àpidu un'errore imbiende is invitos",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ses proende a intrare in una resonada cun una sessione ativa in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk. Ite boles fàghere?",
-    "Leave this page" : "Lassa custa pàgina",
-    "Join here" : "Intra inoghe",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Su navigadore chi ses impreende no est suportadu totu dae Nextcloud. Imprea s'ùrtima versione de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Connessione pèrdida cun su serbidore de signalatzione. Proende a torrare a connètere",
     "Establishing signaling connection is taking longer than expected …" : "Sa creatzione de sa connessione de signalatzione est istentende prus de su tempus prevìdidu ...",
@@ -1046,44 +1044,19 @@ OC.L10N.register(
     "__language_name__" : "sardu",
     "Tasks" : "Fainas",
     "Notes" : "Notas",
-    "There are currently no commands available." : "No b'at cummandos disponìbiles in custu momentu.",
-    "The command does not exist" : "Su cummandu no esistit",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "B'at àpidu un'errore in s'esecutzione de su cummandu. Pedi a chie amministrat de castiare is registros.",
     "You tried to call {user}" : "As proadu a tzerriare a {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Mutida cun %n persones istràngias (Durada {durada})","Mutida cun %n persones istràngias (Durada {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Mutida cun {user2} e {user2} (Durada {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Mutida cun {user1}, {user2} e {user3} (Durada {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Mutida cun {user1}, {user2}, {user3} e {user4} (Durada {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Mutida cun {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
+    "%s invited you to a conversation." : "%s t'at invitadu in una resonada",
+    "You were invited to a conversation." : "T'ant invitadu in una resonada.",
+    "Click the button below to join." : "Incarca su butone a suta pro intrare.",
+    "Join »%s«" : "Intra in »%s«",
     "{user} invited you to a private conversation" : "{user} t'at invitadu in una resonada privada",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Is cummandos sunt una funtzionalidade noa in Nextcloud Talk. Ti permitint de eseguire script in su serbidore Nextcloud. Ddus podes definire cun s'interfache a lìnia de cumandu. Un'esèmpiu de script de calculadora si podet agatare in sa {linkstart}documentatzione{linkend}.",
-    "Moderators" : "Is chi moderant",
-    "Commands" : "Cumandos",
-    "Command" : "Cumandu",
-    "Script" : "Script",
-    "Response to" : "Risposta a ",
-    "Enabled for" : "Ativadu pro",
-    "Hosted high-performance backend" : "Motore de prestatziones artas retzidu.",
-    "SIP configuration is only possible with a high-performance backend." : "Sa cunfiguratzione SiP est possìbile isceti cun unu motore de prestatziones artas.",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Pro installatziones mannas, si diat dèpere seberare unu serbidore de signalatzione de foras. Lassa bòidu pro impreare unu serbidore de signalatzione de intro.",
-    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Cussigiamus de cunfigurare una memòria temporànea distribuida cando impreas Nextcloud Talk cun unu Motore de Prestatziones Artas.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Non mi signales problemas de connetividade in is mutidas cun prus de 4 persones",
     "Copy conversation link" : "Còpia su ligòngiu de sa resonada",
-    "Channel ID or name" : "ID o nùmene de su canale",
-    "Loading" : "Carrighende",
     "Close" : "Serra",
-    "Password protect" : "Bàrdia sa crae",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk est istadu agiornadu, depes torrare a carrigare sa pàgina antis de pòdere cumintzare o intrare in una mutida.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud est istadu agiornadu, torra a carrigare sa pàgina",
-    "Post to conversation" : "Pùblica in sa resonada",
     "An error happened when trying to share your file" : "B'at àpidu un'errore proende a cumpartzire s'archìviu",
     "Failed to join the conversation. Try to reload the page." : "No at fatu a intrare in sa resonada. Proa a torrare a carrigare sa pàgina.",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud est in mantenidura, torra a carrigare sa pàgina",
-    "Lost connection to signaling server. Try to reload the page manually." : "Connessione pèrdida cun su serbidore de signalatzione. Proa a torrare a carrigare sa pàgina a manu.",
-    "Specify commands the users can use in chats" : "Ispetzìfica is commandos chi is utentes podent impreare in sa tzarrada",
-    "TURN server" : "Serbidore TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN s'impreat pro imbiare su tràficu dae is partetzipantes a secus de unu firewall.",
-    "Signaling servers" : "Serbidores de signalatzione",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Unu serbidore de signalatzione de foras podet èssere impreadu a sèberu pro installatziones prus mannas. Lassa bòidu pro impreare unu serbidore de signalatzione de intro."
+    "Lost connection to signaling server. Try to reload the page manually." : "Connessione pèrdida cun su serbidore de signalatzione. Proa a torrare a carrigare sa pàgina a manu."
 },
 "nplurals=2; plural=(n != 1);");
